% Cell array that contains the names of three images
names = { 'buildings1.pgm', 'buildings2.pgm', 'buildings3.pgm' };

% Plot the histogram of a grayscale image using imhist command
figure;
x = imread( names{1} );
imhist( x );

% Compute the histogram of three images using the hist command
figure;
for i = 1:3,
    % Read the i'th image
    x = imread( names{i} );
    % Compute its histogram
    h = hist( double( x(:) ), [ 0:255 ] );
    % Normalize the histogram
    h = h / sum( h );
    % Plot the image, its histogram and its cumulative histogram
    subplot( 3, 3, i );
    imshow( x );
    title( 'Original image' );
    subplot( 3, 3, i + 3 );
    plot( [ 0:255 ], h );
    axis( [ 0 255 0 0.04 ] );
    title( 'Histogram' );
    subplot( 3, 3, i + 6 );
    plot( [ 0:255 ], cumsum( h ) );
    axis( [ 0 255 0 1 ] );
    title( 'Cumulative histogram' );
end

% Compute the histogram of three images after equalization using the hist command
figure;
for i = 1:3,
    % Read the i'th image
    x = imread( names{i} );
    % Perform histogram equalization
    x = histeq( x );
    % Compute its histogram
    h = hist( double( x(:) ), [ 0:255 ] );
    % Normalize the histogram
    h = h / sum( h );
    % Plot the image, its histogram and its cumulative histogram
    subplot( 3, 3, i );
    imshow( x );
    title( 'Original image' );
    subplot( 3, 3, i + 3 );
    plot( [ 0:255 ], h );
    axis( [ 0 255 0 0.04 ] );
    title( 'Histogram' );
    subplot( 3, 3, i + 6 );
    plot( [ 0:255 ], cumsum( h ) );
    axis( [ 0 255 0 1 ] );
    title( 'Cumulative histogram' );
end
